<?php

namespace Ems\Repository;

use Doctrine\ORM\EntityManager;
use Doctrine\DBAL\Connection;

class ResumoRepository {
    /** @var Connection */
    protected $connection;

    public function __construct(
        EntityManager $entityManager
    ) {
        $this->connection = $entityManager->getConnection();
    }

    public function getSituacoesFreq(
        array $params
    ) {
        $sql = <<<SQL
            SELECT
                NRSITUFREQUENCIA,
                NRORG,
                DSSITUFREQUENCIA,
                DSABREVIACAO
            FROM
                PTO_SITUFREQUENCIA
            WHERE
                NRORG IN (:P_NRORG, :P_NRORG_PADRAO) AND
                IDATIVO = 'S' AND
                (
                    TO_DATE(:P_DTMESCOMPETENC, 'DD/MM/YYYY') >= DTINIVIGENCIA OR
                    DTINIVIGENCIA IS NULL
                ) AND
                (
                    TO_DATE(:P_DTMESCOMPETENC, 'DD/MM/YYYY') <= DTFIMVIGENCIA OR
                    DTFIMVIGENCIA IS NULL
                )
            ORDER BY
                DSSITUFREQUENCIA
SQL;

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        $result = $std->fetchAll();

        return $result;
    }

    public function editRowResumoFreq(
        array $params
    ) {
        $sql = <<<SQL
            UPDATE
                PTO_RESUMOSITUFREQ
            SET
                NRSITUFREQUENCIA = :P_NRSITUFREQUENCIA,
                QTREFAPURSITUFREQ = :P_QTREFAPURSITUFREQ,
                CDOPERULTATU = :P_CDOPERADOR,
                DTULTATU = SYSDATE,
                NRORGULTATU = :P_NRORG
            WHERE
                NRORG = :P_NRORG AND
                NRRESUMOSITUFREQ = :P_NRRESUMOSITUFREQ
SQL;

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }

    public function deleteRowResumoFreq(
        array $params
    ) {
        $sql = <<<SQL
            DELETE FROM
                PTO_RESUMOSITUFREQ
            WHERE
                NRORG = :P_NRORG AND
                NRRESUMOSITUFREQ = :P_NRRESUMOSITUFREQ
SQL;

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }

    public function saveRowResumoFreq(
        array $params
    ) {
        $sql = <<<SQL
            INSERT INTO PTO_RESUMOSITUFREQ (
                NRORG,                  NRRESUMOSITUFREQ,       NRPROGOCORRENCIA,
                NRPERIODOAPURACAO,      NRVINCULOM,             NRMOTIVOOCORFREQ,
                DTAPURACAOSITUFREQ,     IDFORCASITUFREQ,        QTREFAPURSITUFREQ,
                QTREFABONSITUFREQ,      QTREFAPUNOVASITUFREQ,   DSOBSERVACAO,
                NRLOTELANCEVENTO,       IDATIVO,                NRORGINCLUSAO,
                DTINCLUSAO,             CDOPERINCLUSAO,         NRORGULTATU,
                DTULTATU,               CDOPERULTATU,           NRSITUFREQNOVA,
                NRSITUFREQUENCIA,       IDCONFIRMADA
            ) VALUES (
                :NRORG,                 :NRRESUMOSITUFREQ,      NULL,
                :NRPERIODOAPURACAO,     :NRVINCULOM,            NULL,
                :DTAPURACAOSITUFREQ,    NULL,                   :QTREFAPURSITUFREQ,
                NULL,                   NULL,                   NULL,
                NULL,                   'S',                    :NRORG,
                SYSDATE,                :CDOPERADOR,            :NRORG,
                SYSDATE,                :CDOPERADOR,            NULL,
                :NRSITUFREQUENCIA,      'S'
            )
SQL;

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
}