/* Tabela IMPOSTONF: Impostos da Nota Fiscal */
/* Descrio: A trigger insere registros na tabela LOGOPERA a partir de alteraes na tabela IMPOSTONF */
/* Objetivo: Gerar um log que vai registrar as alteraes na tabela Impostos da Nota Fiscal,
             utilizando a tabela Geral de Logs de Operaes */
CREATE OR REPLACE TRIGGER LOG_FIS_IMPOSTONF
AFTER DELETE OR INSERT OR UPDATE
ON IMPOSTONF FOR EACH ROW
DECLARE
  V_USUARIO      VARCHAR2(40);
  V_TIPO         VARCHAR2(1);
  V_ITPESQ       VARCHAR2(40);
  V_DESC         VARCHAR2(300);
  V_CDFILLOGOPER VARCHAR2(4);
  V_DTOPER       DATE;
  V_DSREMOTEADDR VARCHAR2(15);
  V_DSREMOTEHOST VARCHAR2(15);
  V_DSSERVERRDM  VARCHAR2(20);
  V_DSSERVMETHOD VARCHAR2(30);
  V_DSREMOTEOPER VARCHAR2(12);
BEGIN
   V_TIPO := '0';
   V_DESC := '';
   V_CDFILLOGOPER := '';

   IF DELETING THEN
      IF :OLD.CDIMPOSTO IS NOT NULL THEN
         V_DESC := V_DESC || 'Imposto=' || :OLD.CDIMPOSTO;
      END IF;

      IF :OLD.IDIMPOSTONF IS NOT NULL THEN
         V_DESC := V_DESC || ' ID=' || :OLD.IDIMPOSTONF;
      END IF;

      IF :OLD.VRCONTABILNF IS NOT NULL THEN
         V_DESC := V_DESC || ' VrContabil=' || ROUND(:OLD.VRCONTABILNF, 5);
      END IF;

      IF :OLD.VRBASECALCNF IS NOT NULL THEN
         V_DESC := V_DESC || ' VrBaseCalc=' || ROUND(:OLD.VRBASECALCNF, 5);
      END IF;

      IF :OLD.VRALIQNF IS NOT NULL THEN
         V_DESC := V_DESC || ' Aliquota=' || ROUND(:OLD.VRALIQNF, 5);
      END IF;

      IF :OLD.VRIMPOSTONF IS NOT NULL THEN
         V_DESC := V_DESC || ' VrImposto=' || :OLD.VRIMPOSTONF;
      END IF;

      IF :OLD.CDFISCALNF IS NOT NULL THEN
         V_DESC := V_DESC || ' CF=' || :OLD.CDFISCALNF;
      END IF;

      V_TIPO         := '3';
      V_ITPESQ       := :OLD.CDFILIAL||:OLD.NRLANCTONF||:OLD.NRIMPOSNF;
      V_CDFILLOGOPER := :OLD.CDFILIAL;
   ELSE
      IF UPDATING THEN
         IF (:OLD.CDIMPOSTO <> :NEW.CDIMPOSTO) OR
            (:OLD.IDIMPOSTONF <> :NEW.IDIMPOSTONF) OR
            (:OLD.VRCONTABILNF <> :NEW.VRCONTABILNF) OR 
            (:OLD.VRBASECALCNF <> :NEW.VRBASECALCNF) OR 
            (:OLD.VRALIQNF <> :NEW.VRALIQNF) OR 
            (:OLD.VRIMPOSTONF <> :NEW.VRIMPOSTONF) OR 
            (:OLD.CDFISCALNF <> :NEW.CDFISCALNF) THEN

            V_TIPO         := '2';
            V_ITPESQ       := :NEW.CDFILIAL||:NEW.NRLANCTONF||:NEW.NRIMPOSNF;
            V_CDFILLOGOPER := :NEW.CDFILIAL;
         END IF;
      ELSE
         V_TIPO         := '1';
         V_ITPESQ       := :NEW.CDFILIAL||:NEW.NRLANCTONF||:NEW.NRIMPOSNF;
         V_CDFILLOGOPER := :NEW.CDFILIAL;
      END IF;

      IF :NEW.CDIMPOSTO IS NOT NULL THEN
         V_DESC := V_DESC || 'Imposto=' || :NEW.CDIMPOSTO;
      END IF;

      IF :NEW.IDIMPOSTONF IS NOT NULL THEN
         V_DESC := V_DESC || ' ID=' || :NEW.IDIMPOSTONF;
      END IF;

      IF :NEW.VRCONTABILNF IS NOT NULL THEN
         V_DESC := V_DESC || ' VrContabil=' || ROUND(:NEW.VRCONTABILNF, 5);
      END IF;

      IF :NEW.VRBASECALCNF IS NOT NULL THEN
         V_DESC := V_DESC || ' VrBaseCalc=' || ROUND(:NEW.VRBASECALCNF, 5);
      END IF;

      IF :NEW.VRALIQNF IS NOT NULL THEN
         V_DESC := V_DESC || ' Aliquota=' || ROUND(:NEW.VRALIQNF, 5);
      END IF;

      IF :NEW.VRIMPOSTONF IS NOT NULL THEN
         V_DESC := V_DESC || ' VrImposto=' || :NEW.VRIMPOSTONF;
      END IF;

      IF :NEW.CDFISCALNF IS NOT NULL THEN
         V_DESC := V_DESC || ' CF=' || :NEW.CDFISCALNF;
      END IF;

   END IF;

   IF V_TIPO <> '0' THEN
      NMUSUARIO(V_USUARIO);
      WEBTUNNING(V_DSREMOTEADDR,
                 V_DSREMOTEHOST,
                 V_DSSERVERRDM,
                 V_DSSERVMETHOD,
                 V_DSREMOTEOPER);
      IF NOT V_DESC IS NULL THEN
         IF NOT V_USUARIO IS NULL THEN
            V_DTOPER := SYSDATE;

            INSERT INTO LOGOPERA
               (NMTABELA,     DTOPERACAO,   NMRESPOPER,
                IDTIPOOPER,   CDPESQITEM,   DSOPERACAO,
                CDFILLOGOPER, DSRDMUSUOPER, DSENDUSUOPER,
                DSNMUSUOPER,  DSMETUSUOPER, CDORESPOPER)
            VALUES
               ('IMPOSTONF',  V_DTOPER, V_USUARIO,
                V_TIPO,      V_ITPESQ, V_DESC, 
                V_CDFILLOGOPER, V_DSSERVERRDM,  V_DSREMOTEADDR,
                V_DSREMOTEHOST, V_DSSERVMETHOD, V_DSREMOTEOPER);
         END IF;
      END IF;
   END IF;
END;
/

